#
# spec file for package libsigscan
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}

%define lname	libsigscan1
Name:           libsigscan
Version:        20231201
Release:        1.1
Summary:        Library for binary signature scanning
License:        LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libsigscan
Source:         https://github.com/libyal/libsigscan/releases/download/%version/libsigscan-experimental-%version.tar.gz
Source2:        https://github.com/libyal/libsigscan/releases/download/%version/libsigscan-experimental-%version.tar.gz.asc
Source9:        %name.keyring
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libbfio) >= 20221025
BuildRequires:  pkgconfig(libcdata) >= 20230108
BuildRequires:  pkgconfig(libcerror) >= 20220101
BuildRequires:  pkgconfig(libcfile) >= 20220106
BuildRequires:  pkgconfig(libclocale) >= 20221218
BuildRequires:  pkgconfig(libcnotify) >= 20220108
BuildRequires:  pkgconfig(libcpath) >= 20220108
BuildRequires:  pkgconfig(libcsplit) >= 20220109
BuildRequires:  pkgconfig(libcthreads) >= 20220102
BuildRequires:  pkgconfig(libuna) >= 20230710
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
libsigscan is a library for binary signature scanning

libsigscan is part of the libyal family of libraries

%package -n %{lname}
Summary:        Library for binary signature scanning
Group:          System/Libraries

%description -n %{lname}
libsigscan is a library for binary signature scanning

%package tools
Summary:        Tools to scan for binary signatures
Group:          Productivity/File utilities
Requires:       %{lname} = %{version}

%description tools
Tools to scan binary files for signatures.

%package devel
Summary:        Development files for libigscan
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libbfio-devel

%description devel
libsigscan is a library for binary signature scanning

This subpackage contains libraries and header files for developing
applications that want to make use of libpff.

%prep
%autosetup -p1

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type --enable-python \
	PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv "%_builddir/rt/"* "%buildroot/"
find "%buildroot" -type f -name "*.la" -delete -print

%post   -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%license COPYING*
%{_libdir}/libsigscan.so.*

%files -n %name-tools
%license COPYING*
%{_bindir}/sigscan
%{_mandir}/man1/sigscan.1%{?ext_man}
%config %{_sysconfdir}/sigscan.conf

%files -n %name-devel
%license COPYING*
%{_includedir}/libsigscan.h
%{_includedir}/libsigscan/
%{_libdir}/libsigscan.so
%{_libdir}/pkgconfig/libsigscan.pc
%{_mandir}/man3/libsigscan.3%{?ext_man}

%files %python_files
%{python_sitearch}/pysigscan.so

%changelog
* Mon Feb  5 2024 Jan Engelhardt <jengelh@inai.de>
- Use python-setuptools for python distutils backport
  gh#libyal/libbde#68
* Fri Dec  1 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231201
  * Improved Python Unicode handling
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Mon Jan  9 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230109
  * Change sto unbounded pattern scan
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Sun Dec 18 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221218
  * No changelog was provided
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Fri Oct 28 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221027
  * Unspecific updates to Python bindings
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update build requirement on libcfile
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Mon Jan 24 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220124
  * No changelog was provided
* Sun May 16 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210419 (a5c92123)
  * No changelog was provided
- Add system-libs.patch
* Thu Dec 24 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to 20201117
* Thu Apr 30 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- remove python2 submodule
* Fri Jan 17 2020 Matej Cepl <mcepl@suse.com>
- update to 20191221
  * Worked on Python wheel support
  * Applied updates and changes for libcdata
- introduced %%{experimental_tag}
- required for recent releases of python-dfVFS
* Wed Apr 17 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v20190103
  * Worked on Python bindings
* Mon Oct  2 2017 Greg.Freemyer@gmail.com
- add python3 binding subpackage
* Thu Feb 16 2017 Greg.Freemyer@gmail.com
- update to v20170124
  * fixed bug in scan tree initialization
  * applied updates
  * fixes for rpmbuild
  * worked on Python 3 support
  * worked on Python bindings
  * worked on setup.py
  * bug fixes
* Wed Jul  1 2015 Greg.Freemyer@gmail.com
- update to v20150627
  * required by plaso v1.3
  * worked on Python bindings
  * fixes in sigscan.conf
- update url field to point to github
- for the python sub-package add a Requires libsigscan
* Wed Mar 25 2015 Greg.Freemyer@gmail.com
- initial package v20150125
